``eradiate.xarray``
===================

.. automodule:: eradiate.xarray
   :members:

``eradiate.xarray.interp``
--------------------------

.. automodule:: eradiate.xarray.interp

.. py:currentmodule:: eradiate.xarray.interp

.. autosummary::
   :toctree: generated/autosummary/

   dataarray_to_rgb
   film_to_angular

``eradiate.xarray._accessors``
------------------------------

.. automodule:: eradiate.xarray._accessors

.. py:currentmodule:: eradiate.xarray._accessors

.. autosummary::
   :toctree: generated/autosummary/

   EradiateDataArrayAccessor
